wget -q --delete-after https://simutrans-germany.com/translator_page/scenarios/scenario_5/download.php
wget -O texts.zip https://simutrans-germany.com/translator_page/scenarios/scenario_5/data/language_pack-Scenario+Tutorial+multipak.zip
